@@ -164,6 +164,7 @@ parse_net_file (SPACE_DSC * dsc,char *filename, NET_CACHE **lastptr,int version
   char line[MAX_LINE + 1];
   char rmt_addr[128];
   char addr6[128];
+  unsigned long tmp_ino;
 
   if (!(file = fopen (filename, "r")))
     {
@@ -180,13 +181,24 @@ parse_net_file (SPACE_DSC * dsc,char *filename, NET_CACHE **lastptr,int version
 	  perror ("malloc");
 	  exit (1);
 	}
-      if (sscanf (line, "%*d: %*x:%x %64[0-9A-Fa-f]:%x %*x %*x:%*x %*x:%*x %*x %*d %*d "
-		  "%Ld", &new->lcl_port, rmt_addr, &new->rmt_port,
-		  &new->ino) != 4)
+      /*
+      if (sscanf (line, 
+#ifdef INO_T_IS_LONG_LONG
+        "%*d: %*x:%x %64[0-9A-Fa-f]:%x %*x %*x:%*x %*x:%*x %*x %*d %*d %Lu",
+#elif defined(INO_T_IS_INT)
+        "%*d: %*x:%x %64[0-9A-Fa-f]:%x %*x %*x:%*x %*x:%*x %*x %*d %*d %u",
+#else
+        "%*d: %*x:%x %64[0-9A-Fa-f]:%x %*x %*x:%*x %*x:%*x %*x %*d %*d %u",
+#endif
+        &new->lcl_port, rmt_addr, &new->rmt_port, &new->ino) != 4)*/
+    if (sscanf (line, 
+        "%*d: %*x:%x %64[0-9A-Fa-f]:%x %*x %*x:%*x %*x:%*x %*x %*d %*d %lu",
+        &new->lcl_port, rmt_addr, &new->rmt_port, &tmp_ino) != 4)
 	{
 	  free (new);
 	  continue;
 	}
+      new->ino = tmp_ino;
       if (strlen(rmt_addr) > 8) {
         sscanf(rmt_addr, "%08X%08X%08X%08X",
             &((struct sockaddr_in6 *)&new->rmt_addr)->sin6_addr.s6_addr32[0],
@@ -194,7 +206,7 @@ parse_net_file (SPACE_DSC * dsc,char *filename, NET_CACHE **lastptr,int version
             &((struct sockaddr_in6 *)&new->rmt_addr)->sin6_addr.s6_addr32[2],
             &((struct sockaddr_in6 *)&new->rmt_addr)->sin6_addr.s6_addr32[3]);
         inet_ntop(AF_INET6, &((struct sockaddr_in6 *)&new->rmt_addr)->sin6_addr, addr6, sizeof(addr6));
-        printf("address %s\n", addr6);
+        /*printf("address %s\n", addr6);*/
       } else {
         sscanf(rmt_addr, "%X",
             &((struct sockaddr_in *) &new->rmt_addr)->sin_addr.s_addr);
@@ -468,7 +480,7 @@ scan_fd (void)
     }
   empty = 1;
   while ((de = readdir (dir)) != NULL)
-    if ((pid = atoi (de->d_name)) != 0)
+    if ((pid = (pid_t)atoi (de->d_name)) != 0)
       {
 	empty = 0;
 	if (asprintf (&path, "%s/%d", PROC_BASE, pid) < 0)
@@ -586,7 +598,7 @@ ask (pid_t pid)
 
   fflush (stdout);
   do {
-    fprintf (stderr, _("Kill process %d ? (y/n) "), pid);
+    fprintf (stderr, _("Kill process %d ? (y/N) "), pid);
     fflush (stderr);
     do {
       if ((ch = getchar ()) == EOF)
@@ -644,7 +656,7 @@ show_files_or_kill (void)
   const struct passwd *pw;
   const char *user, *scan;
   char tmp[10], *path, comm[COMM_LEN + 1];
-  int length, header, first, dummy;
+  int length, header, first, dummy, last_namelen = 0;
   header = 1;
   for (file = files; file; file = file->next)
     if (file->name && (file->items || all))
@@ -655,7 +667,7 @@ show_files_or_kill (void)
 	    header = 0;
 	  }
 	length = 0;
-	for (scan = file->name; *scan; scan++)
+	for (scan = file->name; scan && *scan; scan++)
 	  if (*scan == '\\')
 	    length += printf ("\\\\");
 	  else if (*scan > ' ' && *scan <= '~')
@@ -667,16 +679,18 @@ show_files_or_kill (void)
 	    length += printf ("\\%03o", *scan);
 	if (file->name_space)
 	  length += printf ("/%s", file->name_space->name);
+
+	if (length > 0)
+	  last_namelen=length;
+	else
+	  printf("\n%*.*s",last_namelen,last_namelen," ");
+
 	if (!(file->flags & FLAG_VERB))
 	  {
 	    putchar (':');
 	    length++;
 	  }
-	while (length < NAME_FIELD)
-	  {
-	    putchar (' ');
-	    length++;
-	  }
+
 	first = 1;
 	for (item = file->items; item; item = item->next)
 	  {
@@ -684,6 +698,13 @@ show_files_or_kill (void)
 	      {
 		if (item->type != it_proc)
 		  continue;
+        if ((first==1) && (item->u.proc.ref_set & (REF_FILE|REF_ROOT|REF_CWD|REF_EXE|REF_MMAP))) {
+    while (length < NAME_FIELD)
+    {
+      putchar (' ');
+      length++;
+    }
+        }
 		if (item->u.proc.ref_set & REF_FILE)
 		  printf ("%6d", item->u.proc.pid);
 		if (item->u.proc.ref_set & REF_ROOT)
@@ -748,6 +769,12 @@ show_files_or_kill (void)
 		  printf ("%*s", NAME_FIELD, "");
 		else if (length > NAME_FIELD)
 		  printf ("\n%*s", NAME_FIELD, "");
+        else
+          while (length < NAME_FIELD)
+          {
+            putchar (' ');
+            length++;
+          }
 		printf (" %-8s ", user);
 		switch (item->type)
 		  {
@@ -786,8 +813,6 @@ show_files_or_kill (void)
 	  }
 	if (!(file->flags & FLAG_VERB) || first)
 	  putchar ('\n');
-	if (first)
-	  fprintf (stderr, _("No process references; use -v for the complete list\n"));
 	if (file->flags & FLAG_KILL)
 	  for (item = file->items; item; item = item->next)
 	    kill_item (file, item);
@@ -864,6 +889,7 @@ parse_inet (const char *spec, const char *name_space, int *lcl_port,
   address_match = 0;
   for (here = s; here; here = next ? next + 1 : NULL)
     {
+      printf("here: %s\n", here);
       next = strchr (here, ',');
       if (next)
 	*next = 0;
