@@ -22,6 +22,8 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/ioctl.h>
+#include <libintl.h>
+#define _(String) gettext (String)
 
 #include "comm.h"
 
@@ -105,7 +107,7 @@ sym_ascii =
 static PROC *list = NULL;
 static int width[MAX_DEPTH], more[MAX_DEPTH];
 static int print_args = 0, compact = 1, user_change = 0, pids = 0, by_pid = 0,
-  trunc = 1;
+  trunc = 1, wait_end = 0;
 #ifdef FLASK_LINUX
 static int show_sids    = 0;
 static int show_scontext = 0;
@@ -181,12 +183,12 @@ out_scontext ( security_id_t sid )
 
   rv = security_sid_to_context((int)sid, buf, &len);
   if ( rv ) {
-    out_string("`??'"); /* punt */
+    out_string("`??\'"); /* punt */
   }
   else {
     out_string("`");
     out_string(buf);
-    out_string("'");
+    out_string("\'");
   }
 }
 #endif /*FLASK_LINUX*/
@@ -373,7 +375,7 @@ dump_tree (PROC * current, int level, int rep, int leaf, int last,
     return;
   if (level >= MAX_DEPTH - 1)
     {
-      fprintf (stderr, "MAX_DEPTH not big enough.\n");
+      fprintf (stderr, _("MAX_DEPTH not big enough.\n"));
       exit (1);
     }
   if (!leaf)
@@ -450,11 +452,12 @@ dump_tree (PROC * current, int level, int rep, int leaf, int last,
     {
       for (i = 0; i < current->argc; i++)
 	{
-	  out_char (' ');
+      if (i < current->argc-1) /* Space between words but not at the end of last */
+	    out_char (' '); 
 	  len = 0;
 	  for (here = current->argv[i]; *here; here++)
 	    len += *here > ' ' && *here <= '~' ? 1 : 4;
-	  if (cur_x + len <= output_width - (i == current->argc - 1 ? 0 : 4))
+	  if (cur_x + len <= output_width - (i == current->argc - 1 ? 0 : 4) || !trunc)
 	    for (here = current->argv[i]; *here; here++)
 	      if (*here > ' ' && *here <= '~')
 		out_char (*here);
@@ -591,7 +594,7 @@ read_proc (void)
     }
   empty = 1;
   while ((de = readdir (dir)) != NULL)
-    if ((pid = atoi (de->d_name)) != 0)
+    if ((pid = (pid_t) atoi (de->d_name)) != 0)
       {
 	if (!(path = malloc (strlen (PROC_BASE) + strlen (de->d_name) + 10)))
 	  exit (2);
@@ -627,7 +630,7 @@ read_proc (void)
 	    if (fscanf
 		(file, "%d (%s) %c %d", &dummy, comm, (char *) &dummy,
 		 &ppid) == 4)
-	      */
+ */
 		if (!print_args)
 #ifdef FLASK_LINUX
 		  add_proc(comm, pid, ppid, st.st_uid, NULL, 0, sid);
@@ -668,7 +671,7 @@ read_proc (void)
     free (buffer);
   if (empty)
     {
-      fprintf (stderr, PROC_BASE " is empty (not mounted ?)\n");
+      fprintf (stderr, _("%s is empty (not mounted ?)\n"), PROC_BASE) ;
       exit (1);
     }
 }
@@ -707,42 +710,37 @@ read_stdin (void)
 static void
 usage (void)
 {
-  fprintf (stderr,
-	   "usage: pstree [ -a ] [ -c ] [ -h | -H pid ] [ -l ] [ -n ] "
-	   "[ -p ] [ -u ]\n%14s[ -G | -U ] [ pid | user]\n", "");
-  fprintf (stderr, "       pstree -V\n\n");
-  fprintf (stderr, "    -a     show command line arguments\n");
-  fprintf (stderr, "    -c     don't compact identical subtrees\n");
-  fprintf (stderr,
-	   "    -h     highlight current process and its ancestors\n");
-  fprintf (stderr,
-	   "    -H pid highlight process \"pid\" and its ancestors\n");
-  fprintf (stderr, "    -G     use VT100 line drawing characters\n");
-  fprintf (stderr, "    -l     don't truncate long lines\n");
-  fprintf (stderr, "    -n     sort output by PID\n");
-  fprintf (stderr, "    -p     show PIDs; implies -c\n");
-  fprintf (stderr, "    -u     show uid transitions\n");
+  fprintf (stderr, _("usage: pstree [ -a ] [ -c ] [ -h | -H pid ] [ -l ] [ -n ] [ -p ] [ -u ]\n"));
+  fprintf (stderr, _("              [ -G | -U ] [ pid | user]\n"));
+  fprintf (stderr, _("       pstree -V\n\n"));
+  fprintf (stderr, _("    -a     show command line arguments\n"));
+  fprintf (stderr, _("    -c     don't compact identical subtrees\n"));
+  fprintf (stderr, _("    -h     highlight current process and its ancestors\n"));
+  fprintf (stderr, _("    -H pid highlight process \"pid\" and its ancestors\n"));
+  fprintf (stderr, _("    -G     use VT100 line drawing characters\n"));
+  fprintf (stderr, _("    -l     don't truncate long lines\n"));
+  fprintf (stderr, _("    -n     sort output by PID\n"));
+  fprintf (stderr, _("    -p     show PIDs; implies -c\n"));
+  fprintf (stderr, _("    -u     show uid transitions\n"));
 #ifdef FLASK_LINUX
-  fprintf (stderr, "    -s     show Flask SIDs\n");
-  fprintf (stderr, "    -x     show Flask security contexts\n");
+  fprintf (stderr, _("    -s     show Flask SIDs\n"));
+  fprintf (stderr, _("    -x     show Flask security contexts\n"));
 #endif /*FLASK_LINUX*/
-  fprintf (stderr,
-	   "    -U     use UTF-8 (Unicode) line drawing characters\n");
-  fprintf (stderr, "    -V     display version information\n");
-  fprintf (stderr, "    pid    start at pid, default 1 (init)\n");
-  fprintf (stderr, "    user   show only trees rooted at processes of that "
-	   "user\n\n");
+  fprintf (stderr, _("    -U     use UTF-8 (Unicode)) line drawing characters\n"));
+  fprintf (stderr, _("    -V     display version information\n"));
+  fprintf (stderr, _("    pid    start at pid, default 1 (init))\n"));
+  fprintf (stderr, _("    user   show only trees rooted at processes of that user\n\n"));
   exit (1);
 }
 
 void print_version()
 {
-  fprintf(stderr, "pstree (psmisc) %s\n", VERSION);
-  fprintf(stderr, "Copyright (C) 1993-2002 Werner Almesberger and Craig Small\n\n");
-  fprintf(stderr, "pstree comes with ABSOLUTELY NO WARRANTY.\n");
-  fprintf(stderr, "This is free software, and you are welcome to redistribute it under the terms\n");
-  fprintf(stderr, "of the GNU General Public License.\n");
-  fprintf(stderr, "For more information about these matters, see the files named COPYING.\n");
+  fprintf(stderr, _("pstree (psmisc) %s\n"), VERSION);
+  fprintf(stderr, _("Copyright (C) 1993-2002 Werner Almesberger and Craig Small\n\n"));
+  fprintf(stderr, _("pstree comes with ABSOLUTELY NO WARRANTY.\n"));
+  fprintf(stderr, _("This is free software, and you are welcome to redistribute it under the terms\n"));
+  fprintf(stderr, _("of the GNU General Public License.\n"));
+  fprintf(stderr, _("For more information about these matters, see the files named COPYING.\n"));
 }
 
 
@@ -755,6 +753,7 @@ main (int argc, char **argv)
   pid_t pid, highlight;
   char termcap_area[1024];
   int c;
+  char *tmpstr;
 
   if (ioctl (1, TIOCGWINSZ, &winsz) >= 0)
     if (winsz.ws_col)
@@ -765,6 +764,13 @@ main (int argc, char **argv)
   
   setlocale(LC_ALL, "");
   
+  if ( (tmpstr = strrchr(argv[0],'/'))) {
+    tmpstr++;
+    if (strcmp(tmpstr, "pstree.x11") ==0)
+      wait_end=1;
+  }
+
+
 #ifdef FLASK_LINUX
   while ((c = getopt (argc, argv, "acGhH:npluUVsx")) != EOF)
 #else  /*FLASK_LINUX*/
@@ -794,12 +800,12 @@ main (int argc, char **argv)
 	  usage ();
 	if (!getenv ("TERM"))
 	  {
-	    fprintf (stderr, "TERM is not set\n");
+	    fprintf (stderr, _("TERM is not set\n"));
 	    return 1;
 	  }
 	if (tgetent (termcap_area, getenv ("TERM")) <= 0)
 	  {
-	    fprintf (stderr, "can't get terminal capabilities\n");
+	    fprintf (stderr, _("Can't get terminal capabilities\n"));
 	    return 1;
 	  }
 	if (!(highlight = atoi (optarg)))
@@ -840,12 +846,12 @@ main (int argc, char **argv)
   if (optind == argc - 1) {
     if (isdigit (*argv[optind]))
       {
-	if (!(pid = atoi (argv[optind++])))
+	if (!(pid = (pid_t) atoi (argv[optind++])))
 	  usage ();
       }
     else if (!(pw = getpwnam (argv[optind++])))
       {
-	fprintf (stderr, "No such user name: %s\n", argv[optind - 1]);
+	fprintf (stderr, _("No such user name: %s\n"), argv[optind - 1]);
 	return 1;
       }
   }
@@ -869,9 +875,14 @@ main (int argc, char **argv)
       dump_by_user (find_proc (1), pw->pw_uid);
       if (!dumped)
 	{
-	  fprintf (stderr, "No processes found.\n");
+	  fprintf (stderr, _("No processes found.\n"));
 	  return 1;
 	}
     }
+  if (wait_end == 1) {
+    fprintf(stderr, _("Press return to close\n"));
+    (void)getchar();
+  }
+
   return 0;
 }
