@@ -4,28 +4,30 @@
 { 4,"ILL" },
 { 5,"TRAP" },
 { 6,"ABRT" },
-{ 7,"EMT" },
+{ 6,"IOT" },
+{ 7,"BUS" },
 { 8,"FPE" },
 { 9,"KILL" },
-{ 10,"BUS" },
+{ 10,"USR1" },
 { 11,"SEGV" },
-{ 12,"SYS" },
+{ 12,"USR2" },
 { 13,"PIPE" },
 { 14,"ALRM" },
 { 15,"TERM" },
-{ 16,"URG" },
-{ 17,"STOP" },
-{ 18,"TSTP" },
-{ 19,"CONT" },
-{ 20,"CHLD" },
+{ 16,"STKFLT" },
+{ 17,"CHLD" },
+{ 18,"CONT" },
+{ 19,"STOP" },
+{ 20,"TSTP" },
 { 21,"TTIN" },
 { 22,"TTOU" },
-{ 23,"IO" },
+{ 23,"URG" },
 { 24,"XCPU" },
 { 25,"XFSZ" },
 { 26,"VTALRM" },
 { 27,"PROF" },
 { 28,"WINCH" },
-{ 29,"INFO" },
-{ 30,"USR1" },
-{ 31,"USR2" },
+{ 29,"IO" },
+{ 30,"PWR" },
+{ 31,"SYS" },
+{ 31,"UNUSED" },
